@@ -26,10 +26,6 @@
 #include "processes_atop_p.h"
 #include "process.h"
 
-#include <klocale.h>
-#include <kglobal.h>
-#include <kdebug.h>
-
 #include <QHash>
 #include <QSet>
 #include <QMutableSetIterator>
@@ -542,5 +538,5 @@ bool Processes::isHistoryAvailable() const
 }
 
 }
-#include "processes.moc"
+
 
