@@ -27,16 +27,18 @@
 
 #include "processcore/processes.h"
 #include "processcore/process.h"
+#include "processcore/processcore_debug.h"
 
-#include <kapplication.h>
 #include <kcolorscheme.h>
 #include <kiconloader.h>
-#include <kdebug.h>
-#include <KGlobal>
 #include <KLocalizedString>
+#include <KFormat>
+#include <QApplication>
 #include <QBitmap>
+#include <QDebug>
 #include <QFont>
 #include <QIcon>
+#include <QLocale>
 #include <QPixmap>
 #include <QList>
 #include <QMimeData>
@@ -52,13 +54,13 @@
 #include <sys/types.h>
 #endif
 
-#include "ProcessModel.moc"
+
 
 #ifdef HAVE_XRES
 #include <X11/extensions/XRes.h>
 #endif
 
-extern KApplication* Kapp;
+extern QApplication* Qapp;
 
 static QString formatByteSize(qlonglong amountInKB, int units) {
     enum { UnitsAuto, UnitsKB, UnitsMB, UnitsGB, UnitsTB, UnitsPB };
@@ -84,22 +86,22 @@ static QString formatByteSize(qlonglong amountInKB, int units) {
 
     switch(units) {
       case UnitsKB:
-        return kString.arg(KGlobal::locale()->formatNumber(amountInKB, 0));
+        return kString.arg(QLocale().toString(amountInKB));
       case UnitsMB:
         amount = amountInKB/1024.0;
-        return mString.arg(KGlobal::locale()->formatNumber(amount, 1));
+        return mString.arg(QLocale().toString(amount, 'f', 1));
       case UnitsGB:
         amount = amountInKB/(1024.0*1024.0);
         if(amount < 0.1 && amount > 0.05) amount = 0.1;
-        return gString.arg(KGlobal::locale()->formatNumber(amount, 1));
+        return gString.arg(QLocale().toString(amount, 'f', 1));
       case UnitsTB:
         amount = amountInKB/(1024.0*1024.0*1024.0);
         if(amount < 0.1 && amount > 0.05) amount = 0.1;
-        return tString.arg(KGlobal::locale()->formatNumber(amount, 1));
+        return tString.arg(QLocale().toString(amount, 'f', 1));
       case UnitsPB:
         amount = amountInKB/(1024.0*1024.0*1024.0*1024.0);
         if(amount < 0.1 && amount > 0.05) amount = 0.1;
-        return pString.arg(KGlobal::locale()->formatNumber(amount, 1));
+        return pString.arg(QLocale().toString(amount, 'f', 1));
       default:
           return "";  // error
     }
@@ -139,7 +141,6 @@ ProcessModelPrivate::~ProcessModelPrivate()
 ProcessModel::ProcessModel(QObject* parent, const QString &host)
     : QAbstractItemModel(parent), d(new ProcessModelPrivate)
 {
-    KGlobal::locale()->insertCatalog("processui");  //Make sure we include the translation stuff.  This needs to be run before any i18n call here
     d->q=this;
 #ifdef HAVE_XRES
     int event, error, major, minor;
@@ -407,7 +408,6 @@ bool ProcessModelPrivate::updateXResClientData() {
     return true;
 }
 void ProcessModelPrivate::queryForAndUpdateAllXWindows() {
-//    qDebug() << "updating xres info:" << QTime::currentTime().toString("hh:mm:ss.zzz");
     updateXResClientData();
     Window       *children, dummy;
     unsigned int  count;
@@ -453,7 +453,6 @@ void ProcessModelPrivate::queryForAndUpdateAllXWindows() {
     }
     if(children)
         XFree((char*)children);
-//    qDebug() << "done updating xres info:" << QTime::currentTime().toString("hh:mm:ss.zzz");
 }
 #endif
 void ProcessModelPrivate::setupProcesses() {
@@ -464,7 +463,8 @@ void ProcessModelPrivate::setupProcesses() {
 #endif
         delete mProcesses;
         mProcesses = 0;
-        q->reset();
+        q->beginResetModel();
+        q->endResetModel();
     }
 
     mProcesses = new KSysGuard::Processes(mHostName);
@@ -560,14 +560,12 @@ void ProcessModelPrivate::updateWindowInfo(WId wid, unsigned int properties, boo
 #endif
 
 void ProcessModel::update(long updateDurationMSecs, KSysGuard::Processes::UpdateFlags updateFlags) {
-//    kDebug() << "update all processes: " << QTime::currentTime().toString("hh:mm:ss.zzz");
     if(updateFlags != KSysGuard::Processes::XMemory) {
         d->mProcesses->updateAllProcesses(updateDurationMSecs, updateFlags);
         if(d->mMemTotal <= 0)
             d->mMemTotal = d->mProcesses->totalPhysicalMemory();
     }
 
-//    kDebug() << "finished:             " << QTime::currentTime().toString("hh:mm:ss.zzz");
 #ifdef HAVE_XRES
     //Add all the rest of the windows
     if(d->mHaveXRes && updateFlags.testFlag(KSysGuard::Processes::XMemory))
@@ -826,7 +824,7 @@ void ProcessModelPrivate::beginRemoveRow( KSysGuard::Process *process )
     } else  {
         int row = process->parent->children.indexOf(process);
         if(row == -1) {
-            kDebug(1215) << "A serious problem occurred in remove row.";
+            qCDebug(LIBKSYSGUARD) << "A serious problem occurred in remove row.";
             mRemovingRow = false;
             return;
         }
@@ -1141,14 +1139,14 @@ QString ProcessModelPrivate::getTooltipForUser(const KSysGuard::Process *ps) con
 }
 
 QString ProcessModel::getStringForProcess(KSysGuard::Process *process) const {
-    return xi18nc("Short description of a process. PID, name, user", "<numid>%1</numid>: %2, owned by user %3", (long)(process->pid), process->name, d->getUsernameForUser(process->uid, false));
+    return xi18nc("Short description of a process. PID, name, user", "%1: %2, owned by user %3", (long)(process->pid), process->name, d->getUsernameForUser(process->uid, false));
 }
 
 QString ProcessModelPrivate::getGroupnameForGroup(long gid) const {
     if(mIsLocalhost) {
         QString groupname = KUserGroup(gid).name();
         if(!groupname.isEmpty())
-            return xi18n("%1 (gid: <numid>%2</numid>)", groupname, gid);
+            return xi18n("%1 (gid: %2)", groupname, gid);
     }
     return QString::number(gid);
 }
@@ -1178,6 +1176,8 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
     //This function must be super duper ultra fast because it's called thousands of times every few second :(
     //I think it should be optomised for role first, hence the switch statement (fastest possible case)
 
+    KFormat format;
+
     if (!index.isValid()) {
         return QVariant();
     }
@@ -1342,7 +1342,7 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
         if(process->tracerpid >= 0) {
             KSysGuard::Process *process_tracer = d->mProcesses->getProcess(process->tracerpid);
             if(process_tracer) //it is possible for this to be not the case in certain race conditions
-                tracer = xi18nc("tooltip. name,pid ","This process is being debugged by %1 (<numid>%2</numid>)", process_tracer->name, (long int)process->tracerpid);
+                tracer = xi18nc("tooltip. name,pid ","This process is being debugged by %1 (%2)", process_tracer->name, (long int)process->tracerpid);
         }
         switch(index.column()) {
         case HeadingName: {
@@ -1367,14 +1367,14 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
                 } else if(process->name == "kthreadd") {
                     tooltip += i18n("<b>KThreadd</b> manages kernel threads. The children processes run in the kernel, controlling hard disk access, etc.<br/>");
                 }
-                tooltip    += xi18nc("name column tooltip. first item is the name","<b>%1</b><br />Process ID: <numid>%2</numid>", process->name, (long int)process->pid);
+                tooltip    += xi18nc("name column tooltip. first item is the name","<b>%1</b><br />Process ID: %2", process->name, (long int)process->pid);
             }
             else {
                 KSysGuard::Process *parent_process = d->mProcesses->getProcess(process->parent_pid);
                 if(parent_process) { //In race conditions, it's possible for this process to not exist
-                    tooltip    = xi18nc("name column tooltip. first item is the name","<b>%1</b><br />Process ID: <numid>%2</numid><br />Parent: %3<br />Parent's ID: <numid>%4</numid>", process->name, (long int)process->pid, parent_process->name, (long int)process->parent_pid);
+                    tooltip    = xi18nc("name column tooltip. first item is the name","<b>%1</b><br />Process ID: %2<br />Parent: %3<br />Parent's ID: %4", process->name, (long int)process->pid, parent_process->name, (long int)process->parent_pid);
                 } else {
-                    tooltip    = xi18nc("name column tooltip. first item is the name","<b>%1</b><br />Process ID: <numid>%2</numid><br />Parent's ID: <numid>%3</numid>", process->name, (long int)process->pid, (long int)process->parent_pid);
+                    tooltip    = xi18nc("name column tooltip. first item is the name","<b>%1</b><br />Process ID: %2<br />Parent's ID: %3", process->name, (long int)process->pid, (long int)process->parent_pid);
                 }
             }
             if(process->numThreads >= 1)
@@ -1480,14 +1480,14 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
             if(process->vmURSS != -1) {
                 //We don't have information about the URSS, so just fallback to RSS
                 if(d->mMemTotal > 0)
-                    tooltip += i18n("Memory usage: %1 out of %2  (%3 %)<br />", KGlobal::locale()->formatByteSize(process->vmURSS * 1024), KGlobal::locale()->formatByteSize(d->mMemTotal*1024), process->vmURSS*100/d->mMemTotal);
+                    tooltip += i18n("Memory usage: %1 out of %2  (%3 %)<br />", format.formatByteSize(process->vmURSS * 1024), format.formatByteSize(d->mMemTotal*1024), process->vmURSS*100/d->mMemTotal);
                 else
-                    tooltip += i18n("Memory usage: %1<br />", KGlobal::locale()->formatByteSize(process->vmURSS * 1024));
+                    tooltip += i18n("Memory usage: %1<br />", format.formatByteSize(process->vmURSS * 1024));
             }
             if(d->mMemTotal > 0)
-                tooltip += i18n("RSS Memory usage: %1 out of %2  (%3 %)", KGlobal::locale()->formatByteSize(process->vmRSS * 1024), KGlobal::locale()->formatByteSize(d->mMemTotal*1024), process->vmRSS*100/d->mMemTotal);
+                tooltip += i18n("RSS Memory usage: %1 out of %2  (%3 %)", format.formatByteSize(process->vmRSS * 1024), format.formatByteSize(d->mMemTotal*1024), process->vmRSS*100/d->mMemTotal);
             else
-                tooltip += i18n("RSS Memory usage: %1", KGlobal::locale()->formatByteSize(process->vmRSS * 1024));
+                tooltip += i18n("RSS Memory usage: %1", format.formatByteSize(process->vmRSS * 1024));
             return tooltip;
         }
         case HeadingSharedMemory: {
@@ -1497,9 +1497,9 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
                 return tooltip;
             }
             if(d->mMemTotal >0)
-                tooltip += i18n("Shared library memory usage: %1 out of %2  (%3 %)", KGlobal::locale()->formatByteSize((process->vmRSS - process->vmURSS) * 1024), KGlobal::locale()->formatByteSize(d->mMemTotal*1024), (process->vmRSS-process->vmURSS)*100/d->mMemTotal);
+                tooltip += i18n("Shared library memory usage: %1 out of %2  (%3 %)", format.formatByteSize((process->vmRSS - process->vmURSS) * 1024), format.formatByteSize(d->mMemTotal*1024), (process->vmRSS-process->vmURSS)*100/d->mMemTotal);
             else
-                tooltip += i18n("Shared library memory usage: %1", KGlobal::locale()->formatByteSize((process->vmRSS - process->vmURSS) * 1024));
+                tooltip += i18n("Shared library memory usage: %1", format.formatByteSize((process->vmRSS - process->vmURSS) * 1024));
 
             return tooltip;
         }
@@ -1508,17 +1508,17 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
             QString tooltip = "<qt><p style='white-space:pre'>";
             //FIXME - use the formatByteRate functions when added
             tooltip += ki18n("Characters read: %1 (%2 KiB/s)<br>Characters written: %3 (%4 KiB/s)<br>Read syscalls: %5 (%6 s⁻¹)<br>Write syscalls: %7 (%8 s⁻¹)<br>Actual bytes read: %9 (%10 KiB/s)<br>Actual bytes written: %11 (%12 KiB/s)")
-                .subs(KGlobal::locale()->formatByteSize(process->ioCharactersRead))
+                .subs(format.formatByteSize(process->ioCharactersRead))
                 .subs(QString::number(process->ioCharactersReadRate/1024))
-                .subs(KGlobal::locale()->formatByteSize(process->ioCharactersWritten))
+                .subs(format.formatByteSize(process->ioCharactersWritten))
                 .subs(QString::number(process->ioCharactersWrittenRate/1024))
                 .subs(QString::number(process->ioReadSyscalls))
                 .subs(QString::number(process->ioReadSyscallsRate))
                 .subs(QString::number(process->ioWriteSyscalls))
                 .subs(QString::number(process->ioWriteSyscallsRate))
-                .subs(KGlobal::locale()->formatByteSize(process->ioCharactersActuallyRead))
+                .subs(format.formatByteSize(process->ioCharactersActuallyRead))
                 .subs(QString::number(process->ioCharactersActuallyReadRate/1024 ))
-                .subs(KGlobal::locale()->formatByteSize(process->ioCharactersActuallyWritten))
+                .subs(format.formatByteSize(process->ioCharactersActuallyWritten))
                 .subs(QString::number(process->ioCharactersActuallyWrittenRate/1024))
                 .toString();
             return tooltip;
@@ -1998,7 +1998,7 @@ QMimeData *ProcessModel::mimeData(const QModelIndexList &indexes) const
                     textCsv += ',';
                     textPlain += ", ";
                 }
-                textHtml += "<td>" + Qt::escape(display) + "</td>";
+                textHtml += "<td>" +  QString(display).toHtmlEscaped() + "</td>";
                 textPlain += display;
                 display.replace('"',"\"\"");
                 textCsv += '"' + display + '"';
